pub struct TreeNode<T> {
pub value: T,
/* private fields */
}Expand description
A single tree node
Fields
value: TImplementations
Sourceimpl<T> TreeNode<T>
impl<T> TreeNode<T>
Sourcepub fn clear_children(&mut self)
pub fn clear_children(&mut self)
Remove all children of this node
Sourcepub fn remove_child(
parent: &NodeRef<T>,
child: &NodeRef<T>,
) -> Option<NodeRef<T>>
pub fn remove_child( parent: &NodeRef<T>, child: &NodeRef<T>, ) -> Option<NodeRef<T>>
Removes child from parent, returning the detached node when found.
Sourcepub fn append_child(parent: &NodeRef<T>, child: NodeRef<T>) -> bool
pub fn append_child(parent: &NodeRef<T>, child: NodeRef<T>) -> bool
Appends child, moving it from its current parent when necessary.
Returns false when the operation would create a tree cycle.
Sourcepub fn insert_before(
parent: &NodeRef<T>,
child: NodeRef<T>,
reference: &NodeRef<T>,
) -> bool
pub fn insert_before( parent: &NodeRef<T>, child: NodeRef<T>, reference: &NodeRef<T>, ) -> bool
Inserts child immediately before reference, moving it from its
current parent when necessary.
pub fn is_inclusive_ancestor(ancestor: &NodeRef<T>, node: &NodeRef<T>) -> bool
Sourcepub fn insert_child_at(parent: &NodeRef<T>, index: usize, child: NodeRef<T>)
pub fn insert_child_at(parent: &NodeRef<T>, index: usize, child: NodeRef<T>)
Insert a child at a given position
Sourcepub fn add_child_value(parent: &NodeRef<T>, value: T) -> NodeRef<T>
pub fn add_child_value(parent: &NodeRef<T>, value: T) -> NodeRef<T>
Create a child with value and add it to parent
Sourcepub fn replace_child(
parent: &NodeRef<T>,
index: usize,
new_child: NodeRef<T>,
) -> Option<NodeRef<T>>
pub fn replace_child( parent: &NodeRef<T>, index: usize, new_child: NodeRef<T>, ) -> Option<NodeRef<T>>
Replace child at given index
Sourcepub fn find_children_by<F>(&self, predicate: F) -> Vec<NodeRef<T>> ⓘ
pub fn find_children_by<F>(&self, predicate: F) -> Vec<NodeRef<T>> ⓘ
Find direct children matching predicate
Sourcepub fn clone_node(&self, deep: bool) -> NodeRef<T>where
T: Clone,
pub fn clone_node(&self, deep: bool) -> NodeRef<T>where
T: Clone,
Clone node (optionally deep)