pub struct Tree<T> {
pub root: NodeRef<T>,
}Expand description
Represents a tree with a single root node
Fields
root: NodeRef<T>Implementations
Sourceimpl Tree<HtmlNodeType>
impl Tree<HtmlNodeType>
Sourcepub fn get_elements_by_tag_name(
&self,
tag_name: &str,
) -> Vec<NodeRef<HtmlNodeType>> ⓘ
pub fn get_elements_by_tag_name( &self, tag_name: &str, ) -> Vec<NodeRef<HtmlNodeType>> ⓘ
Returns all elements with the given tag name
Sourcepub fn get_element_by_id(&self, id: &str) -> Option<NodeRef<HtmlNodeType>>
pub fn get_element_by_id(&self, id: &str) -> Option<NodeRef<HtmlNodeType>>
Returns the element with the given id
Sourcepub fn get_elements_by_class_name(
&self,
class_name: &str,
) -> Vec<NodeRef<HtmlNodeType>> ⓘ
pub fn get_elements_by_class_name( &self, class_name: &str, ) -> Vec<NodeRef<HtmlNodeType>> ⓘ
Returns all elements that have the given class
Sourcepub fn inner_text(node: &NodeRef<HtmlNodeType>) -> String
pub fn inner_text(node: &NodeRef<HtmlNodeType>) -> String
Returns the concatenated text content of this node (including children)
Sourcepub fn set_text_content(node: &NodeRef<HtmlNodeType>, new_text: &str)
pub fn set_text_content(node: &NodeRef<HtmlNodeType>, new_text: &str)
Replace all text content of this node with the given string
Sourcepub fn collect_text_by_tag(&self, tag_name: &str) -> Vec<String>
pub fn collect_text_by_tag(&self, tag_name: &str) -> Vec<String>
指定したタグ名の要素のテキストノードをすべて集める
Sourceimpl<T: Clone> Tree<T>
impl<T: Clone> Tree<T>
Sourcepub fn map<U, F>(&self, f: F) -> Tree<U>
pub fn map<U, F>(&self, f: F) -> Tree<U>
Map each node value to another type, returning a new Tree
Sourcepub fn map_with_node<U, F>(&self, f: F) -> Tree<U>
pub fn map_with_node<U, F>(&self, f: F) -> Tree<U>
Map using the NodeRef itself (for access to parent/children)